Learn R Programming

hystReet (version 0.0.3)

read_hystreet_csv: Read downloaded data from the hystreet webpage to data.frames

Description

Read downloaded data from the hystreet webpage to data.frames

Usage

read_hystreet_csv(path, ...)

Value

data.frame with parsed data from hystreet API

Arguments

path

character (required): path to the downloaded csv file

...

(optional): arguments passed to utils::read.csv2()

Function version

0.0.1

Author

Johannes Friedrich

Examples

Run this code
if (FALSE) {
## read data from downloaded csv file data
df <- hystReet::read_hystreet_csv("~/Downloads/hystreet.csv")

 }

Run the code above in your browser using DataLab