Learn R Programming

hystReet (version 0.0.3)

get_hystreet_stats: Get statistics from the Hystreet Project via Hystreet API

Description

Get statistics from the Hystreet Project via Hystreet API

Usage

get_hystreet_stats(verbose = FALSE, API_token = NULL)

Value

data.frame with parsed data from hystreet API

Arguments

verbose

logical (optional): Show more verbose output?

API_token

character (optional): API key to get access to Hystreet API

Function version

0.0.2

Author

Johannes Friedrich

Examples

Run this code
if (FALSE) {
 get_hystreet_stats(TRUE)
}

Run the code above in your browser using DataLab