powered by
Read downloaded data from the hystreet webpage to data.frames
read_hystreet_csv(path, ...)
data.frame with parsed data from hystreet API
character (required): path to the downloaded csv file
(optional): arguments passed to utils::read.csv2()
utils::read.csv2()
0.0.1
Johannes Friedrich
if (FALSE) { ## read data from downloaded csv file data df <- hystReet::read_hystreet_csv("~/Downloads/hystreet.csv") }
Run the code above in your browser using DataLab